@@ -457,6 +457,7 @@ class WordType(caching.base.CachingMixin,models.Model):
                                 WHERE buckeyebrowser_underlying.WordType_id
                                     =buckeyebrowser_wordtype.id)"""})
         word = qs.get(pk = self.pk)
+        phones = word.ur.split(" ")
         patterns = []
         for i in range(len(phones)):
             patt = phones[:i] #Substitutions
@@ -511,7 +512,7 @@ class WordType(caching.base.CachingMixin,models.Model):
         patterns = []
         SPprob = 0.0
         BPprob = 0.0
-        phones = input_string.split(" ")
+        phones = word.ur.split(" ")
         for i in range(len(phones)):
             patt = [any_segment] * i
             patt.append(phones[i])
