@@ -7,7 +7,7 @@ import os
 
 from django.conf import settings
 
-from .helper import loadFile
+from .helper import loadFile,fetch_media_resource
 
 def get_dist():
     from django.db import connection
